@@ -3,13 +3,11 @@ from .base import CustomField
 from ..list import ClickUpList
 from ..services import clickup_api
 from ..services.cache import ClientListsRegistry
+from ..utils.exceptions.lists import ClientListNotFound
 from ..utils.types import RawCustomField
 from ..utils.validators import RelationValidator
 
 
-class ClientListNotFound(Exception):
-    """Raised when client list class not found."""
-
 class RelationField(CustomField):
     TYPE = "list_relationship"
     VALIDATOR = RelationValidator
@@ -30,7 +28,7 @@ class RelationField(CustomField):
             related_list = ClientListsRegistry.get(related_list)
             if not related_list:
                 raise ClientListNotFound(
-                    f"There is no such class: {related_list_name}"
+                    f"There is no such list: {related_list_name}"
                 )
 
         return related_list
@@ -40,11 +38,16 @@ class RelationField(CustomField):
         value: ClickUpList,
         raw_field: RawCustomField
     ) -> None:
-        current_values = raw_field.get("value") 
+        current_values = raw_field.get("value")
 
         if not current_values:
             current_values = []
 
+        if current_values:
+            existed_ids = list(map(lambda item: item['id'], current_values))
+            if value.id in existed_ids:
+                return
+
         raw_field['value'] = [*current_values, dict(id=value.id)]
 
     def get_value(self, raw_field: RawCustomField) -> List[ClickUpList]:
