@@ -1,25 +1,19 @@
 from __future__ import annotations
+from datetime import datetime
 from functools import cached_property
 from typing import Any, List, Union, Optional, Generator
 
 from .services import clickup_api
 from .services.cache import CustomFieldsCache, ClientListsRegistry
+from .utils.date_format import ClickupDateFormat 
+from .utils.exceptions.fields import (
+    ReadOnlyTaskField, RequiredFieldMissing, InvalidOption
+)
+from .utils.exceptions.tasks import TaskFromWrongList
+from .utils.exceptions.lists import ListIdNotFound
 from .utils.types import RawTask, RawCustomField
  
 
-class TaskIdNotFound(Exception):
-    """Raised, when there is no `id` found in task object."""
-
-class TaskFromWrongList(Exception):
-    """
-    Raised, when we fetch task by id from correct space, but for wrong list
-    """
-
-class ReadOnlyTaskField(Exception):
-    """
-    Raised, when there was a try of manual update of task's `id` field.
-    """
-
 class ClientListsLookup(type):
     """
     Metaclass that will store each client class to the registry.
@@ -38,10 +32,16 @@ class ClientListsLookup(type):
         cls = type.__new__(cls, name, bases, attrs)
 
         if bases: 
+            list_id = attrs.get("LIST_ID")
+
+            if list_id is None:
+                raise ListIdNotFound(
+                    f"Please, provide valid LIST_ID for your "
+                    f"`{cls.__name__}` class."
+                )
+
             ClientListsRegistry.update({
-                name: cls 
-                for base in bases
-                if base == ClickUpList
+                name: cls for base in bases if base == ClickUpList
             })
 
         return cls
@@ -78,6 +78,55 @@ class ClickUpList(metaclass=ClientListsLookup):
             "`id` will be added to the task when you will get/create a task" 
         )
 
+    @property
+    def due_date(self) -> Optional[datetime]:
+        timestamp = self._raw_task.get("due_date")
+        
+        if timestamp is None:
+            return 
+
+        return ClickupDateFormat.timestamp_to_datetime(timestamp)
+
+    @due_date.setter
+    def due_date(self, value: Any) -> Optional[datetime]:
+        if not isinstance(value, datetime):
+            raise TypeError("`due_date` attribute must be `datetime`") 
+
+        timestamp = ClickupDateFormat.datetime_to_timestamp(value)
+
+        self._raw_task['due_date'] = timestamp 
+
+    @property
+    def status(self) -> Optional[str]:
+        raw_status = self._raw_task.get('status')
+
+        if raw_status is None:
+            return
+
+        return raw_status['status'].capitalize()
+
+    @status.setter
+    def status(self, value: Any) -> None:
+        conditions = [
+            value is not None,
+            isinstance(value, str),
+            value.capitalize() in self.statuses
+        ]
+
+        if not all(conditions):
+            raise InvalidOption(
+                f"`{value}` is not a valid status.\n"
+                f"List of possible statuses: {self.statuses}"
+            )
+
+        self._raw_task['status'] = dict(status=value) 
+
+    @cached_property
+    def statuses(self) -> List[str]:
+        raw_list = clickup_api.get_list(self.LIST_ID)
+        statuses = raw_list['statuses'] 
+        return list(map(lambda status: status['status'].capitalize(), statuses))
+
     @property
     def name(self) -> Optional[str]:
         return self._raw_task.get("name")
@@ -142,9 +191,10 @@ class ClickUpList(metaclass=ClientListsLookup):
         page = 0
         tasks = clickup_api.get_batch_tasks(cls.LIST_ID, page).get('tasks')
 
-        yield tasks if tasks else []
-
-        page += 1
+        while tasks:
+            yield tasks if tasks else []
+            tasks = clickup_api.get_batch_tasks(cls.LIST_ID, page).get('tasks')
+            page += 1
     
     @classmethod
     def get_by_id(cls, task_id: str):
@@ -178,9 +228,17 @@ class ClickUpList(metaclass=ClientListsLookup):
         Method, that will get current raw_task 
         values and push them to ClickUp.
         """
+        if not self.name:
+            raise RequiredFieldMissing(
+                "You must set `name` attribute before creating a task"
+            ) 
+
         custom_fields = self._fields_cache.get()
         body = dict(
             name=self.name,
+            description=self.description,
+            status=self.status,
+            due_date=self._raw_task.get('due_date'),
             custom_fields=custom_fields
         )
         raw_task = clickup_api.create_task(self.LIST_ID, **body)
@@ -195,14 +253,19 @@ class ClickUpList(metaclass=ClientListsLookup):
         3) Update custom fields
         """
         if not self.id:
-            raise TaskIdNotFound("Can not update unexisted Task")
+            raise RequiredFieldMissing(
+                "You can't update task with proper `id`.\n"
+                "Maybe you wanted to `create` a new task?"
+            )
 
-        body = dict(
+        default_fields = dict(
             name=self.name,
-            description=self.description
+            description=self.description,
+            status=self.status,
+            due_date=self._raw_task.get('due_date')
         )
 
-        self._raw_task = clickup_api.update_task(self.id, **body)
+        self._raw_task = clickup_api.update_task(self.id, **default_fields)
  
         custom_fields = self._fields_cache.get()
 
