@@ -3,9 +3,10 @@ from .drop_down import DropDownValidator
 from .email import EmailValidator
 from .number import NumberValidator, PositiveNumberValidator
 from .relation import RelationValidator
-from .string import StringValidator, NumericStringValidator
+from .string import StringValidator
 from .url import UrlValidator
 from .uuid import UuidValidator
 from .date import DateValidator
 from .labels import LabelsValidator
 from .base import ForbidValuesValidator
+from .phone import PhoneValidator
